##
## Copyright (C) 2000-2004  SWsoft
## All rights reserved.
##
## PleskDomaind management
##

package HSPC::PM::PluginEngine::BankAccount;

use strict;

use SWsoft::protect;
 
use HSPC::WebSystemLib;
use HSPC::Localization qw(:DEFAULT string string_lang);
use HSPC::WebPage;
use HSPC::DataRequest;

use HSPC::Logger qw(sw_atrace sw_die sw_log);
use HSPC::DataCheck;

use HSPC::Error;

use Error  qw(:try);
use HSPC::Exc::Fatal;

use HSPC::WebSystemLib;

use HSPC::MT::PP::Constants;
use HSPC::MT::GM::Constants qw(:card_pr_type);

use HSPC::MT::Billing::Constants qw(:DEFAULT :setup);
use HSPC::MT::PM::Constants qw(SW_PM_STATUS_UNCHECKED SW_PM_STATUS_OK SW_PM_STATUS_TXT SW_PM_STATUS_DELETED);

use HSPC::Billing::Hash;

use HSPC::MT::GM::Constants qw(:card_pr_type);

use HSPC::PM::PluginEngine;
use base qw{HSPC::PM::PluginEngine};

sub new {
	my $class = shift;
	my %h = (
		'session_args' => undef,
		@_,
	);

	sw_die(__PACKAGE__." : session args not defined")
		unless ( ref($h{'session_args'}) 
			&& UNIVERSAL::isa(ref($h{'session_args'}),'HSPC::PM::SessionArgs') );

	if($h{'session_args'}) {
		$h{'session_args'}->screen_ids({
			list => '09.01',
			view => '09.02',
			edit => '09.03',
			add  => '09.04',
			edoc => '09.05',
			key  => '09.06',
		});

		$h{'session_args'}->bread_crumbs({
			1 => { title_id => 'commerce_director_uc', url => q{$ENV{CC_BASEURL}.'/site.cgi/em/dash'} },
			2 => { title_id => 'bank_transfers_uc', url => q{$ENV{CC_BASEURL}.'/site.cgi/cc/dash_bd_bm_bt'} },
			3 => { title_id => 'bank_accounts_uc',	url => q{$self->session_args->page->{'common_url'}} },
		});
	}

	return $class->SUPER::new(%h);
}


sub build_path {
	my $self = shift;
	my %h = (
		step => undef,
		@_
	);

	my $trace = &sw_atrace("step => $h{step}");

	my $result_step = $self->SUPER::build_path();

	if ( $self->session_args->bread_crumbs->{$result_step} ) {
		$self->session_args->page->add_header_nav_path(
			path => {
				title_id => $self->session_args->bread_crumbs->{$result_step}->{title_id},
				url => eval($self->session_args->bread_crumbs->{$result_step}->{url})
			},
			force => 1
		);
	}

	if ( $h{step} && $self->session_args->bread_crumbs->{$h{step}} ) {
		$self->session_args->page->add_header_nav_path(
			path => {
				title_id => $self->session_args->bread_crumbs->{$h{step}}->{title_id},
				url => eval($self->session_args->bread_crumbs->{$h{step}}->{url})
			},
			force => 1
		);
	}

	$h{step} = ($h{step} ? $h{step} : $result_step);
	$h{step}++;

	$trace->add("Res = $h{step}");
	return $h{step};
}

##-----------------------------------------------------------------------------
## >>class
sub teaser_edit_docs {
    my $self = shift;

	my $trace = sw_atrace();
	my $sargs = $self->session_args;

	unless ( $sargs->paymethod_obj && $sargs->paymethod_obj->id() ) {
		sw_die(__PACKAGE__ . ": Paymethod object is undefined");
	}

	my $main_page = $sargs->page;

	if ( $sargs->draw_header() ) {
		if ($ENV{COMPREP}) {
			$ENV{COMPREP}->node(edit => 1)->{title_hash}->{title} =
				string('ba_edit_docs') . ' #' . $sargs->paymethod_obj->id;
			$main_page->title(pages => []);
		} else {
			$main_page->header();
			$main_page->title(
				'title' => string('ba_edit_docs') . ' #' . $sargs->paymethod_obj->id,
				'devscreen_id' => $self->get_screen_id( page => 'edoc' ),
			);
			$self->build_path( step => 3 );

			$main_page->tab();
		}
	}
	$main_page->statuses();

	my $url_ext = "/act,pay_doc/pmethod_id," . $sargs->paymethod_obj->id;

	## draw account general settings edit screen
	$self->edit_docs(
		obj        => $sargs->paymethod_obj,
		page       => $main_page,
		is_admin   => $sargs->is_admin,
		act_url_ext  => $url_ext,
	);

	return undef;
}


sub popup_url {
	return undef if !$ENV{COMPREP};
	return $ENV{COMPREP}->link(
		alias=>"payment_methods_bt_act_popup",{plugin_type=>'bt'}
	);
}


sub __title_single_id {
	return 'bank_account';
}

sub __title_plural_id {
	return 'bank_accounts_uc';
}

1;
