## Second presentation class for payment plugins
## (created only for compibility with HSPC::PluginHelper::Base)
## First look in HSPC::PluginConfig::PP
package HSPC::PP::PluginEngine;

use HSPC::WebSystemLib;
use HSPC::PluginToolkit::General;
use HSPC::Localization qw(:DEFAULT string current_lang);
use HSPC::MT::PluginTools qw(set_request_data get_request_data);
use HSPC::MT::PluginConfig::PP;

#######################################################################
### Help functions
#######################################################################

sub get_help_url {
	my $class     = shift;
	my $action    = sw_argparam("act") || sw_uriparam('act');
	my $language  = uc( current_lang() );
	my $vendor_id = $ENV{security_obj}->account_no();

	my $url;
	if ( $action eq 'new' ) {
		my $sub_type = sw_uriparam('plugin_type')
		  || sw_argparam('plugin_type')
		  || substr( $ENV{COMPREP}->node->{alias}, length('payment_plugins_') );

		if (
			$class->_get_summary_page(
				sub_type  => uc($sub_type),
				language  => $language,
				vendor_id => $vendor_id,
			)
		  )
		{
			$url = HSPC::PluginToolkit::General::get_help_url(
				action      => 'summary',
				plugin_type => 'PP',
				template_id => 'na',
				sub_type    => uc($sub_type),
				language    => $language,
				vendor_id   => $vendor_id,
			);
		}
		return $url;
	}
	elsif ( $action eq 'wizard' ) {
		$action = 'new';
	}

	my $template_id = get_request_data('plugin_template_id');

	if ($template_id) {
		if (
			$class->_get_plugin_help(
				action      => $action,
				template_id => $template_id,
				language    => $language,
			)
		  )
		{
			$url = HSPC::PluginToolkit::General::get_help_url(
				action      => $action,
				plugin_type => 'PP',
				template_id => $template_id,
				language    => $language,
			);
		}
	}
	return $url;
}

sub _get_plugin_help {
	my $class = shift;
	my %h     = (
		action      => undef,
		template_id => undef,
		language    => undef,
		@_
	);
	my $action      = $h{action};
	my $template_id = $h{template_id};
	my $language    = $h{language};

	my $help;
	my $template = HSPC::MT::PluginConfig::PP->find_presentation_template(
		plugin_type => 'PP',
		template_id => $template_id,
	);

	eval "use $template;";
	unless ($@) {
		if ( $template->can('get_help_page') ) {
			set_request_data('plugin_template_id', $template_id );
			set_request_data('plugin_type', 'PP' );
			eval {
				$help = $template->get_help_page(
					action   => $action,
					language => $language,
				);
			};
			if ($@) {
				sw_log_warn( "Error get_help_page: " . $@ );
			}
		}
	}
	return $help;
}

sub get_help_page {
	my $class = shift;
	my %h     = (
		action      => undef,
		template_id => undef,
		language    => undef,
		sub_type    => undef,
		vendor_id   => undef,
		@_
	);
	my $action    = $h{action};
	my $sub_type  = $h{sub_type};
	my $language  = $h{language};
	my $vendor_id = $h{vendor_id};

	if ( $action eq 'summary' ) {
		return $class->_get_summary_page(
			sub_type  => $sub_type,
			language  => $language,
			vendor_id => $vendor_id
		);
	}

	return $class->_get_plugin_help(
		template_id => $h{template_id},
		action      => $action,
		language    => $language,
	);
}

sub _get_summary_page {
	my $class = shift;
	my %h    = (
		sub_type  => undef,
		language  => undef,
		vendor_id => undef,
		@_
	);

	my $sub_type  = $h{sub_type};
	my $language  = $h{language};
	my $vendor_id = $h{vendor_id};

	my $tmpls = HSPC::MT::PluginConfig::PP->find_templates(
		sub_type    => $sub_type,
		plugin_type => 'PP',
		vendor_id   => $vendor_id,
	);

	my @abouts;
	foreach my $tmpl (@$tmpls) {
		my $about = $class->_get_plugin_help(
			template_id => $tmpl,
			action      => 'about',
			language    => $language,
		);
		next unless $about;

		my $txt;
		$txt->{id}    = $tmpl;
		$txt->{title} = $class->_get_plugin_title( template_id => $tmpl );
		$txt->{txt}   = $about;

		push( @abouts, $txt );
	}
	my $url = $ENV{q}->url( -path_info => 1 );

	my $cont;
	$cont =
	  sw_web_parse_template( __PACKAGE__, 'summary_help_page.tmpl',
		{ abouts => \@abouts, url => $url } )
	  if scalar(@abouts);
	return $cont;
}

sub _get_plugin_title {
	my $class = shift;
	my %h     = (
		template_id => undef,
		@_
	);
	my $template_id = $h{template_id};

	my $title;
	my $template = HSPC::MT::PluginConfig::PP->find_mt_template(
		plugin_type => 'PP',
		template_id => $template_id,
	);

	eval "use $template;";
	unless ($@) {
		if ( $template->can('get_title') ) {
			eval { $title = $template->get_title(); };
			if ($@) {
				sw_log_warn( "Error get_title: " . $@ );
			}
		}
	}
	return $title;
}

#######################################################################
### (END) Help functions
#######################################################################

1;
