package HSPC::PluginWizard::DM;

use strict;
use HSPC::WebSystemLib;
use HSPC::WebPage;
use HSPC::Logger qw(sw_die sw_log sw_log_warn);

##use HSPC::MT::DM::RegEngine;
use HSPC::MT::PluginConfig::DM;
use HSPC::MT::PluginTools qw(set_request_data get_request_data);
use HSPC::UIStepsPage;

use vars qw(@ISA);
@ISA = qw(HSPC::UIStepsPage);

sub init_self_steps {
	my $self = shift;
	$self->add_step({title_id => "gen_settings", code => 'gen',});
	$self->add_step({title_id => 'dm_plugin_configuration', code => 'plugin'});
}

sub teaser_wizard {
	my ($class,%h) = @_;
	
	my $self;
	
	my $act = sw_argparam("act") || sw_uriparam('act');
	
	if ($act eq 'new') {
		$self = $class->new();
		$self->{obj} = HSPC::MT::PluginConfig::DM->new();
		$self->{obj}->vendor_id($ENV{security_obj}->account_no());
		$self->{obj}->plugin_type('DM');
		$self->{obj}->currency('USD');
	} else {
		$self = 0;
	}

	my $page = HSPC::WebPage->new({
		common_url => $ENV{COMPREP}->link(alias => 'domain_plugins_new'),
	});
		
	my $res = $class->teaser_run(
		session_code => 'HSPC_PLUGIN',
		page         => $page,
		steps        => $self,
	);

	return $res;
}

sub teaser_step_gen {
	my $self = shift;
	my $page = $self->page();

	my $obj = $self->{obj};

	$page->title(pages => []);
	$self->form_open();
	$page->edit_view_input(
		title_id => 'dm_plugin_conf_name',
		view_name  => 'config_name',
		not_empty  => 1,
		obj_attr   => 'name',
		object     => $obj,
		max_length => 255,
	);
	my $templates = HSPC::MT::PluginConfig->find_templates(
		plugin_type => 'DM',
		vendor_id   => $obj->vendor_id,
	);
	$page->edit_view_combo(
		title_id => 'dm_plugin_template',
		view_name => 'template_id',
		options   => [
			sort {lc $a->[1] cmp lc $b->[1]} map{[$_,$_]} @{$templates}
		],
		not_empty     => 1,
		options_plain => 1,
		no_default => 1,
		value => $obj->template_id(),
	);
	$page->edit_view_input(
		view_name => 'plugin_currency',
		title_id => 'dm_currency',
		size => 15,
		max_length => 15,
		value => $obj->currency(),
	);
##	$page->edit_view_check(
##		title_id  =>'active',
##		view_name =>'is_active',
##		value     => 1,
##		is_checked=> $obj->is_active == 1 ? 1 : 0
##	);
	$self->form_close(new_btns=>'back_next');
	return {STATUS => 'OK'};
}

sub teaser_step_plugin {
	my $self = shift;

	my $page = $self->page();

	my $obj = $self->{obj};

	$page->title(pages => []);
	$self->form_open(is_multipart => 1);

	set_request_data('plugin_config_id', $obj->id());
	set_request_data('plugin_vendor_id', $obj->vendor_id());
	set_request_data('plugin_template_id', $obj->template_id());

	my $pr_template = $obj->find_presentation_template();

	eval "use $pr_template;";
	## TODO: handle situation, when no presentation template or it doesn't contain edit_config_form method

	$page->row_open();
	$page->cell_content(
		value => $pr_template->edit_config_form( config => $obj->config_data() ),
	);
	$page->row_close();

	$self->form_close(new_btns=>'cancel_back_finish');

	return {STATUS => 'OK'};
}

sub process_step_gen{
	my $self = shift;
	my $obj = $self->{obj};

	my $template_id = $obj->template_id();

	$obj->template_id(sw_argparam('template_id'));
	$obj->name(sw_argparam('name'));
	$obj->currency(sw_argparam('plugin_currency'));
	$obj->is_active(1);

	if(!$obj->id()){
		$obj->save();
		$obj->delete();
	}

	if($template_id ne $obj->template_id()){
		$self->_clear_next_steps_data();
	}

	set_request_data('plugin_config_id', $obj->id());
	set_request_data('plugin_vendor_id', $obj->vendor_id());
	set_request_data('plugin_template_id', $obj->template_id());

	return {STATUS=>'PROCESS'};
}

sub process_step_plugin {
	my $self = shift;

	my $obj = $self->{obj};
	my $pr_template = $obj->find_presentation_template();

	set_request_data('plugin_config_id', $obj->id());
	set_request_data('plugin_vendor_id', $obj->vendor_id());
	set_request_data('plugin_template_id', $obj->template_id());

	eval "use $pr_template;";
	## TODO: handle situation, when no presentation template or it doesn't contain collect_config_data method

	my $collect_result = $pr_template->collect_config_data(
		config => $obj->config_data()
	);
	$obj->config_data($collect_result->{config});

	return {STATUS=>'PROCESS'} if sw_argparam('btn_back');

	if (UNIVERSAL::can($pr_template, 'validate_config_data')){
		sw_log("Try to verify config data");
		my $res = $pr_template->validate_config_data(
			config => $collect_result->{config}
		);
		if (!$res->{is_valid}){
			sw_log_warn("Config validated: ERRORS");

			my $error_str = join ("<br>", map {$_->{message}} @{$res->{error_list}});
			$self->add_error(
				string => $error_str
			);
			return {step_inc => 0};
		}
		sw_log("Config validated: OK");
	} else {
		sw_log("Plugin has no ability to validate config data");
	}

	my $process_result = $obj->process_config_data(
		callback_email => $collect_result->{callback_email}
	);
	if (!$process_result->{is_success}){
		$self->add_error(
			string => "Error occurred: ".$process_result->{message}
		);
		return {step_inc => 0};
	}
	return {STATUS=>'PROCESS'};
}

sub process_url
{
	my $self = shift;
	return $self->page->get_browse_url.'/act,wizard';
}

sub handle_finish {
	my $self = shift;

	my $plugin = HSPC::MT::PluginConfig::DM->find_plugin(
		plugin_id => $self->{obj}->id(),
		vendor_id => $self->{obj}->vendor_id(),
	);
	if($plugin){
		$self->add_error(string => "Fatal error: plugin can't be saved.");
		return {step_inc => 0};
	}

	$self->{obj}->save();
	$self->{free_session} = 1;

	return sw_web_redirect_comprep(
		alias => 'domain_plugins',
		{sl=>'configuration_added_ok'}
	);
}

sub handle_cancel {
	my $self = shift;
	$self->{free_session} = 1;

	return sw_web_redirect_comprep(
		alias => 'domain_plugins',
	);
}

sub get_help_url {
	return "";

	my $class = shift;

	my $act = sw_uriparam('act');
	my ($plugin_id,$action,$template_id,$vendor_id);
	if($act eq 'new'){
		$plugin_id = undef;
		$action = 'about';
		$template_id = get_request_data('plugin_template_id');
		$vendor_id = get_request_data('plugin_vendor_id') || $ENV{security_obj}->account_no();
	}
	elsif($act eq 'wizard'){
		$plugin_id = get_request_data('plugin_config_id');
		$action = 'new';
		$template_id = get_request_data('plugin_template_id');
		$vendor_id = get_request_data('plugin_vendor_id') || $ENV{security_obj}->account_no();
	} else {
		return undef;
	}

##	return HSPC::MT::DM::RegEngine->get_help_url(
##		plugin_id => $plugin_id,
##		action => $action,
##		template_id => $template_id,
##		vendor_id => $vendor_id
##	);
}

sub _clear_next_steps_data {
		my $self = shift;
		
		## clear data that was filled on steps after that one
		$self->{obj}->config_data({});		
}

1;

